@@ -6,8 +6,9 @@ import dbus
 import gnome.gconf as gconf
 import pango
 import cairo
+import simplejson as json
 import xml.dom.minidom as xmlparser
-import urllib2 
+import urllib2
 import urllib
 PATH = "/apps/Maemo/digghomewidget"
 CATGR = "/apps/Maemo/digghomewidget/selected_category"
@@ -35,33 +36,28 @@ class diggLoader(gobject.GObject):
         self.list = None
 
     def read_and_return(self, data):#handle, data, result, read_bytes):
-        doc = xmlparser.parseString(data)
+        #doc = xmlparser.parseString(data)
+        doc = json.loads(data);
         if doc != None:
-            stories = doc.getElementsByTagName("story")
+            #stories = doc.getElementsByTagName("story")
+            stories = doc["stories"]
             if len(stories) == 0:
                 return None
             list = []
             for story in stories:
-                title = story.getElementsByTagName("title")[0]
-                href = story.getElementsByTagName("shorturl")[0]
-                title = title.childNodes[0].data
-                href = href.getAttribute("short_url")
-                diggs = story.getAttribute("diggs")
-                topic = story.getElementsByTagName("topic")[0]
-                topic = topic.getAttribute("name")
+                title = story["title"]
+                href = story["permalink"]
+                diggs = str(story["diggs"])
+                topic = story["topic"]["name"]
                 item = diggItem(title, href, topic, diggs) 
                 if self.load_thumbnails:
                     thumbnail = None
-                    thumbnail = story.getElementsByTagName("thumbnail")
-                    if thumbnail.length > 0:
-                        thumbnail = thumbnail[0]
-                        thumbnail = thumbnail.getAttribute("src")
+                    thumbnail = story["thumbnails"]["thumb"]
                     try:
                         if thumbnail != None and thumbnail != "":
                             g = urllib.urlopen(thumbnail)
                             img = g.read()
                             item.thumbnail = img
-                        #print item.thumbnail
                     except:
                         item.thumbnail = None
                 list.append(item)
@@ -70,16 +66,12 @@ class diggLoader(gobject.GObject):
 
     def get_toplist(self, container="", topic="", count=2, hotness="top"):
         selected = ""
-        if topic != "":
-            selected = "topic/" + topic + "/"
         if container != "":
-            container = container.replace("&", "_")
-            selected = "container/" + container + "/"
-        params = urllib.urlencode({"count":count, "appkey":"2788b5db0429e01726e233ba59a7d287", "container":container})
+            container = container.replace(" ", "_")
+            container = container.lower()
+        params = urllib.urlencode({"limit":count, "appkey":"2788b5db0429e01726e233ba59a7d287", "topic":container})
         try:
-#            url = "http://services.digg.com/stories/"+selected+hotness+"?%s" % params
-            url = "http://services.digg.com/1.0/endpoint?method=story.getTop&%s" % params
-            print url
+            url = "http://services.digg.com/2.0/story.getTopNews?%s" % params
             f = urllib2.urlopen(url)
             data = f.read()
             self.read_and_return(data)
@@ -270,14 +262,16 @@ class DiggHomePlugin(hildondesktop.HomePluginItem):
             
         self.categories = []
         self.categories.append("")
-        self.categories.append("Technology")
-        self.categories.append("World&Business")
+        self.categories.append("Business")
         self.categories.append("Entertainment")
         self.categories.append("Gaming")
-        self.categories.append("Science")
-        self.categories.append("Sports")
         self.categories.append("Lifestyle")
         self.categories.append("Offbeat")
+        self.categories.append("Politics")
+        self.categories.append("Science")
+        self.categories.append("Sports")
+        self.categories.append("Technology")
+        self.categories.append("World News")
         if temp_first == False:
             self.count = 2
             self.checkbox_active = True 
@@ -359,14 +353,16 @@ class DiggHomePlugin(hildondesktop.HomePluginItem):
         selector = hildon.TouchSelector(text = True) 
         selector.connect("changed", self.selection_changed)
         selector.append_text("All")
-        selector.append_text("Technology")
-        selector.append_text("World&Business")
+        selector.append_text("Business")
         selector.append_text("Entertainment")
         selector.append_text("Gaming")
-        selector.append_text("Science")
-        selector.append_text("Sports")
         selector.append_text("Lifestyle")
         selector.append_text("Offbeat")
+        selector.append_text("Politics")
+        selector.append_text("Science")
+        selector.append_text("Sports")
+        selector.append_text("Technology")
+        selector.append_text("World News")
         selector.set_column_selection_mode(hildon.TOUCH_SELECTOR_SELECTION_MODE_SINGLE)
         categoryPicker = hildon.PickerButton(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)
         categoryPicker.set_alignment(0.0, 0.5, 1.0, 1.0)
@@ -460,7 +456,7 @@ class DiggHomePlugin(hildondesktop.HomePluginItem):
 #                self.vbox.remove(child)
 #            self.vbox.set_size_request(-1, self.count*(70+1)-1)
 #            self.set_size_request(300, cursize[1]-(sep*(70+1)))
-            
+        
 #            self.resize(300, cursize[1]-(sep*(70+1)))
             self.update_button(self)
 
